==> qmmp_0.8.1.orig.tar.bz2: qmmp-0.8.1/src/plugins/Input/cdaudio/translations/cdaudio_plugin_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE">
<context>
    <name>DecoderCDAudioFactory</name>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="45"/>
        <source>CD Audio Plugin</source>
        <translation>CD-Audio-Modul</translation>
    </message>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="90"/>
        <source>About CD Audio Plugin</source>
        <translation>Über CD-Audio-Modul</translation>
    </message>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="91"/>
        <source>Qmmp CD Audio Plugin</source>
        <translation>Qmmp CD-Audio-Modul</translation>
    </message>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="92"/>
        <source>Compiled against libcdio-%1 and libcddb-%2</source>
        <translation>Kompiliert mit libcdio-%1 und libcddb-%2</translation>
    </message>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="94"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autor: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="95"/>
        <source>Usage: open cdda:/// using Add URL dialog or command line</source>
        <translation>Verwendung: Geben Sie cdda:/// in den „URL hinzufügen“-Dialog oder in die Befehlszeile ein</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>CD Audio Plugin Settings</source>
        <translation>Einstellungen CD-Audio-Modul</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Override device:</source>
        <translation>Einhängepunkt des CD-Laufwerks:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="42"/>
        <source>Limit cd speed:</source>
        <translation>CD-Geschwindigkeit begrenzen:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="62"/>
        <source>Use cd-text</source>
        <translation>CD-Text verwenden</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="69"/>
        <source>CDDB</source>
        <translation>CDDB</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="78"/>
        <source>Use HTTP instead of CDDBP</source>
        <translation>HTTP anstatt CDDBP verwenden</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="88"/>
        <source>Server:</source>
        <translation>Server:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="95"/>
        <source>Path:</source>
        <translation>Pfad:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="105"/>
        <source>Port:</source>
        <translation>Port:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="117"/>
        <source>Clear CDDB cache</source>
        <translation>CDDB-Zwischenspeicher löschen</translation>
    </message>
</context>
</TS>

==> qmmp-0.12.18.tar.bz2: qmmp-0.12.18/src/plugins/Input/cdaudio/translations/cdaudio_plugin_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de">
<context>
    <name>DecoderCDAudioFactory</name>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="51"/>
        <source>CD Audio Plugin</source>
        <translation>CD-Audio-Modul</translation>
    </message>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="98"/>
        <source>About CD Audio Plugin</source>
        <translation>Über CD-Audio-Modul</translation>
    </message>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="99"/>
        <source>Qmmp CD Audio Plugin</source>
        <translation>Qmmp CD-Audio-Modul</translation>
    </message>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="100"/>
        <source>Compiled against libcdio-%1 and libcddb-%2</source>
        <translation>Kompiliert mit libcdio-%1 und libcddb-%2</translation>
    </message>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="102"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Geschrieben von: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="103"/>
        <source>Usage: open cdda:/// using Add URL dialog or command line</source>
        <translation>Verwendung: Geben Sie cdda:/// in den „URL hinzufügen“-Dialog oder in die Befehlszeile ein</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>CD Audio Plugin Settings</source>
        <translation>Einstellungen CD-Audio-Modul</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Override device:</source>
        <translation>Einhängepunkt des CD-Laufwerks:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="42"/>
        <source>Limit cd speed:</source>
        <translation>CD-Geschwindigkeit begrenzen:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="62"/>
        <source>Use cd-text</source>
        <translation>CD-Text verwenden</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="69"/>
        <source>CDDB</source>
        <translation>CDDB</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="78"/>
        <source>Use HTTP instead of CDDBP</source>
        <translation>HTTP anstatt CDDBP verwenden</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="88"/>
        <source>Server:</source>
        <translation>Server:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="95"/>
        <source>Path:</source>
        <translation>Pfad:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="105"/>
        <source>Port:</source>
        <translation>Port:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="117"/>
        <source>Clear CDDB cache</source>
        <translation>CDDB-Zwischenspeicher löschen</translation>
    </message>
</context>
</TS>
